<?php declare(strict_types=1);

namespace EuKit\Base\Services;

use EuKit\Base\Interfaces\ThemeServiceStartup;

/**
 * Class WidgetServiceStartup
 * @package EuKit\Base\Services
 */
class WidgetServiceStartup implements ThemeServiceStartup
{
    /**
     * @var iterable
     */
    private $registeredWidgets;

    /**
     * @var iterable
     */
    private $unregisteredWidgets;

    public function unregisterWidgets(iterable $widgets = []): void
    {
        $this->unregisteredWidgets = $widgets;
    }

    public function registerWidgets(iterable $widgets = []): void
    {
        $this->registeredWidgets = $widgets;
    }

    public function setup(): void
    {
        $this->unregisterWidgets([
            'WP_Widget_Pages',
            'WP_Widget_Links',
            'WP_Widget_Search',
            'WP_Widget_Archives',
            'WP_Widget_Meta',
            'WP_Widget_Calendar',
            'WP_Widget_Categories',
            'WP_Widget_Recent_Posts',
            'WP_Widget_Recent_Comments',
            'WP_Widget_RSS',
            'WP_Widget_Tag_Cloud',
            'WP_Nav_Menu_Widget',
        ]);

        add_action('widgets_init', function () {

            if ($this->registeredWidgets) {
                foreach ($this->registeredWidgets as $widget) {
                    register_widget($widget);
                }
            }

            if ($this->unregisteredWidgets) {
                foreach ($this->unregisteredWidgets as $widget) {
                    unregister_widget($widget);
                }
            }
        });
    }
}
