<?php

namespace EuKit\Base\ViewModels;

use EuKit\Base\Parts\NewsMLArticle;
use SimpleXMLIterator;
use EuKit\Base\Parts\Image;
use EuKit\Base\Parts\Concept;
use Everyware\Concepts\Concepts;
use Infomaker\Imengine\Imengine;
use Everyware\Concepts\ConceptPost;
use Infomaker\Everyware\Support\NewRelicLog;
use EuKit\Base\Parts\ArticleBodyPresentation;
use Infomaker\Everyware\Support\GenericPropertyObject;
use Infomaker\Everyware\NewsML\NewsMLTransformerManager;
use Infomaker\Everyware\NewsML\Parsers\RelatedLinksParser;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;
use Tightenco\Collect\Support\Collection;

/**
 * Class ArticlePage
 * @package EuKit\Base
 */
class ArticlePage extends Page
{
    public function __construct(NewsMLArticle $article)
    {
        $articleBody = $article->getParsedBody();
        $articleBodyPresentation = new ArticleBodyPresentation($article);

        $propertyObject = new GenericPropertyObject();
        $propertyObject->fill($article->getProperties());
        $propertyObject->fill([
            'teaserImage' => $this->getTeaserImage($article),
            'body' => $articleBody->generateContent($articleBodyPresentation),
            'relatedArticles' => $articleBody->allOfType('x-im/articlex'),
        ]);

        $propertyObject->fill($this->getConceptData($article));
        parent::__construct($propertyObject);
    }

    protected function getTeaserImage(NewsMLArticle $article)
    {
        $articleTeaser = $article->getNewsMLTeaser();
        $image = $articleTeaser ? $articleTeaser->getImage() : null;

        if ($image !== null) {
            $image->set('text', $articleTeaser->title);
            $image = new Image($image);
        }

        return $image ? $image->getViewData() : null;
    }

    private function getConceptData(NewsMLArticle $article): array
    {
        return [
            'authors' => $this->extraxtViewData($article->getAuthors()),
            'tags' => $this->extraxtViewData($article->getTags()),
            'places' => $this->extraxtViewData($article->getFilteredPlaces()),
            'categories' => $this->extraxtViewData($article->getCategories()),
            'channels' => $this->extraxtViewData($article->getChannels())
        ];
    }

    private function extraxtViewData(Collection $collection)
    {
        return $collection->map(function (Concept $concept) {
            return (new RelatedConcept($concept))->getViewData();
        });
    }
}
